@@ -69,11 +69,7 @@ static void
 set_tooltip(GladeXML *xml, GtkWidget *widget,
 	    const gchar *prop_name, const gchar *prop_value)
 {
-    if (GTK_IS_TOOL_ITEM (widget))
-	gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (widget), xml->priv->tooltips,
-				   prop_value, NULL);
-    else
-	gtk_tooltips_set_tip(xml->priv->tooltips, widget, prop_value, NULL);
+    gtk_tooltips_set_tip(xml->priv->tooltips, widget, prop_value, NULL);
 }
 
 static void
@@ -381,14 +377,6 @@ menu_item_set_use_stock (GladeXML *xml, GtkWidget *w,
 
 	    gtk_label_set_text(GTK_LABEL(child), stock_item.label);
 	    gtk_label_set_use_underline(GTK_LABEL(child), TRUE);
-
-	    if (stock_item.keyval)
-		gtk_widget_add_accelerator (w,
-					    "activate",
-					    glade_xml_ensure_accel(xml),
-					    stock_item.keyval,
-					    stock_item.modifier,
-					    GTK_ACCEL_VISIBLE);
 	} else {
 	    g_warning("could not look up stock id '%s'", stock_id);
 	}
@@ -421,11 +409,7 @@ static void
 entry_set_invisible_char (GladeXML *xml, GtkWidget *w,
 			  const gchar *name, const gchar *value)
 {
-    gunichar c;
-
-    c = g_utf8_get_char_validated (value, strlen (value));
-    if (c > 0)
-        gtk_entry_set_invisible_char (GTK_ENTRY (w), c);
+    gtk_entry_set_invisible_char (GTK_ENTRY (w), value [0]);
 }
 
 static void
@@ -436,82 +420,6 @@ button_set_response_id (GladeXML *xml, GtkWidget *w,
 		       GINT_TO_POINTER (INT (value)));
 }
 
-static void
-toggle_tool_button_set_active (GladeXML *xml, GtkWidget *w,
-			       const char *name, const char *value)
-{
-    gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (w),
-				       BOOL (value));
-}
-
-static void
-tool_button_set_icon (GladeXML *xml, GtkWidget *w,
-		      const char *name, const char *value)
-{
-    GdkPixbuf *pb;
-    GtkWidget *image;
-    char *file;
-
-    file = glade_xml_relative_file (xml, value);
-    pb = gdk_pixbuf_new_from_file (file, NULL);
-    g_free (file);
-
-    if (!pb) {
-	g_warning ("Couldn't find image file: %s", value);
-	return;
-    }
-
-    image = gtk_image_new_from_pixbuf (pb);
-    g_object_unref (pb);
-
-    gtk_widget_show (image);
-    gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (w), image);
-}
-
-static void
-combo_box_set_items (GladeXML *xml, GtkWidget *w,
-		     const char *name, const char *value)
-{
-    GtkListStore *store;
-    GtkCellRenderer *cell;
-    gchar *items, *items_end, *item_start, *item_end;
-    GtkTreeIter iter;
-
-    /* If the "items" property is set, we create a simple model with just
-       one column of text. */
-    store = gtk_list_store_new (1, G_TYPE_STRING);
-    gtk_combo_box_set_model (GTK_COMBO_BOX (w), GTK_TREE_MODEL (store));
-
-    /* GtkComboBoxEntry creates the cell renderer itself, but we have to set
-       the column containing the text. */
-    if (GTK_IS_COMBO_BOX_ENTRY (w)) {
-	gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (w), 0);
-    } else {
-	cell = gtk_cell_renderer_text_new ();
-	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (w), cell, TRUE);
-	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (w), cell,
-					"text", 0,
-					NULL);
-    }
-
-    /* Now add the items one at a time. */
-    items = g_strdup (value);
-    items_end = &items[strlen (items)];
-    item_start = items;
-    while (item_start < items_end) {
-	item_end = strchr (item_start, '\n');
-	if (item_end == NULL)
-	    item_end = items_end;
-	*item_end = '\0';
-
-	gtk_list_store_append (store, &iter);
-	gtk_list_store_set (store, &iter, 0, item_start, -1);
-
-	item_start = item_end + 1;
-    }
-    g_free (items);
-}
-
 static void
 menuitem_build_children(GladeXML *self, GtkWidget *w,
 			GladeWidgetInfo *info)
@@ -809,7 +717,6 @@ toolbar_build_children (GladeXML *xml, GtkWidget *parent,
 	    !strcmp (childinfo->child->classname, "radio") ||
 	    !strcmp (childinfo->child->classname, "button")) {
 	    const char *label = NULL, *stock = NULL, *group_name = NULL;
-	    const char *tooltip = NULL;
 	    char *icon = NULL;
 	    gboolean use_stock = FALSE, active = FALSE, new_group = FALSE;
 	    gboolean use_underline = FALSE;
@@ -841,7 +748,7 @@ toolbar_build_children (GladeXML *xml, GtkWidget *parent,
 		} else if (!strcmp (name, "visible")) {
 		    /* ignore for now */
 		} else if (!strcmp (name, "tooltip")) {
-		    tooltip = value;
+		    /* ignore for now */
 		} else if (!strcmp (name, "use_underline")) {
 		    use_underline = BOOL (value);
 		} else if (!strcmp (name, "inconsistent")) {
@@ -855,8 +762,16 @@ toolbar_build_children (GladeXML *xml, GtkWidget *parent,
 	       here, partly because GTK+ doesn't have direct support for stock
 	       toggle & radio items. */
 	    if (use_stock) {
-		stock = label;
-		label = NULL;
+		GtkStockItem item;
+
+		if (gtk_stock_lookup (label, &item)) {
+		    /* Set stock to label, so the icon is created below. */
+		    stock = label;
+		    label = item.label;
+
+		    /* Most stock items have mnemonic accelerators. */
+		    use_underline = TRUE;
+		}
 	    }
 
 	    if (stock) {
@@ -880,26 +795,24 @@ toolbar_build_children (GladeXML *xml, GtkWidget *parent,
 		child = gtk_toolbar_append_element (
 		    GTK_TOOLBAR (parent),
 		    GTK_TOOLBAR_CHILD_TOGGLEBUTTON, NULL,
-		    label, tooltip, NULL, iconw, NULL, NULL);
-		gtk_toggle_button_set_active
-		    (GTK_TOGGLE_BUTTON (child), active);
+		    label, NULL, NULL, iconw, NULL, NULL);
+		gtk_toggle_button_set_active(
+		    GTK_TOGGLE_BUTTON (child), active);
 	    } else if (!strcmp (childinfo->child->classname, "radio")) {
 		child = gtk_toolbar_append_element (
 		    GTK_TOOLBAR (parent),
 		    GTK_TOOLBAR_CHILD_RADIOBUTTON, NULL,
-		    label, tooltip, NULL, iconw, NULL, NULL);
+		    label, NULL, NULL, iconw, NULL, NULL);
 
 		if (group_name) {
 		    g_object_set (G_OBJECT (child),
 				  "group", glade_xml_get_widget (xml, group_name),
 				  NULL);
 		}
-		gtk_toggle_button_set_active
-		    (GTK_TOGGLE_BUTTON (child), active);
 	    } else
 		child = gtk_toolbar_append_item (
 		    GTK_TOOLBAR (parent),
-		    label, tooltip, NULL, iconw, NULL, NULL);
+		    label, NULL, NULL, iconw, NULL, NULL);
 	    
 	    /* GTK+ doesn't support use_underline directly, so we have to hack
 	       it. */
@@ -913,11 +826,7 @@ toolbar_build_children (GladeXML *xml, GtkWidget *parent,
 	    glade_xml_set_common_params (xml, child, childinfo->child);
 	} else {
 	    child = glade_xml_build_widget (xml, childinfo->child);
-
-	    if (GTK_IS_TOOL_ITEM (child))
-		gtk_toolbar_insert (GTK_TOOLBAR (parent), GTK_TOOL_ITEM (child), -1);
-	    else
-		gtk_toolbar_append_widget (GTK_TOOLBAR (parent), child, NULL, NULL);
+	    gtk_toolbar_append_widget (GTK_TOOLBAR (parent), child, NULL, NULL);
 	}
     }
 }
@@ -1121,15 +1030,6 @@ combo_find_internal_child(GladeXML *xml, GtkWidget *parent,
     return NULL;
 }
 
-static GtkWidget *
-combo_box_entry_find_internal_child(GladeXML *xml, GtkWidget *parent,
-				    const gchar *childname)
-{
-    if (!strcmp(childname, "entry"))
-	return gtk_bin_get_child(GTK_BIN(parent));
-    return NULL;
-}
-
 void
 _glade_init_gtk_widgets(void)
 {
@@ -1168,12 +1068,7 @@ _glade_init_gtk_widgets(void)
     glade_register_custom_prop (GTK_TYPE_LIST_ITEM, "label", list_item_set_label);
     glade_register_custom_prop (GTK_TYPE_BUTTON, "response_id", button_set_response_id);
     glade_register_custom_prop (GTK_TYPE_ENTRY, "invisible_char", entry_set_invisible_char);
-    glade_register_custom_prop (GTK_TYPE_TOGGLE_TOOL_BUTTON, "active", toggle_tool_button_set_active);
-    glade_register_custom_prop (GTK_TYPE_TOOL_BUTTON, "icon", tool_button_set_icon);
-    glade_register_custom_prop (GTK_TYPE_COMBO_BOX, "items", combo_box_set_items);
 
-    glade_register_widget (GTK_TYPE_ABOUT_DIALOG, NULL,
-			   NULL, NULL);
     glade_register_widget (GTK_TYPE_ACCEL_LABEL, glade_standard_build_widget,
 			   NULL, NULL);
     glade_register_widget (GTK_TYPE_ALIGNMENT, glade_standard_build_widget,
@@ -1202,8 +1097,6 @@ _glade_init_gtk_widgets(void)
 			   glade_standard_build_children, combo_find_internal_child);
     glade_register_widget (GTK_TYPE_COMBO_BOX, glade_standard_build_widget,
 			   NULL, NULL);
-    glade_register_widget (GTK_TYPE_COMBO_BOX_ENTRY, glade_standard_build_widget,
-			   glade_standard_build_children, combo_box_entry_find_internal_child);
     glade_register_widget (GTK_TYPE_CTREE, glade_standard_build_widget,
 			   clist_build_children, NULL);
     glade_register_widget (GTK_TYPE_CURVE, glade_standard_build_widget,
@@ -1220,10 +1113,6 @@ _glade_init_gtk_widgets(void)
 			   expander_build_children, NULL);
     glade_register_widget (GTK_TYPE_FILE_CHOOSER, glade_standard_build_widget,
 			   NULL, NULL);
-    glade_register_widget (GTK_TYPE_FILE_CHOOSER_DIALOG, glade_standard_build_widget,
-			   gtk_dialog_build_children, dialog_find_internal_child);
-    glade_register_widget (GTK_TYPE_FILE_CHOOSER_BUTTON, glade_standard_build_widget,
-			   NULL, NULL);
     glade_register_widget (GTK_TYPE_FILE_SELECTION, NULL,
 			   glade_standard_build_children, filesel_find_internal_child);
     glade_register_widget (GTK_TYPE_FIXED, glade_standard_build_widget,
@@ -1254,8 +1143,6 @@ _glade_init_gtk_widgets(void)
 			   NULL, NULL);
     glade_register_widget (GTK_TYPE_HSEPARATOR, glade_standard_build_widget,
 			   NULL, NULL);
-    glade_register_widget (GTK_TYPE_ICON_VIEW, glade_standard_build_widget,
-			   NULL, NULL);
     glade_register_widget (GTK_TYPE_IMAGE, glade_standard_build_widget,
 			   NULL, NULL);
     glade_register_widget (GTK_TYPE_IMAGE_MENU_ITEM, glade_standard_build_widget,
@@ -1276,8 +1163,6 @@ _glade_init_gtk_widgets(void)
 			   glade_standard_build_children, NULL);
     glade_register_widget (GTK_TYPE_MENU_ITEM, glade_standard_build_widget,
 			   menuitem_build_children, NULL);
-    glade_register_widget (GTK_TYPE_MENU_TOOL_BUTTON, glade_standard_build_widget,
-			   NULL, NULL);
     glade_register_widget (GTK_TYPE_MESSAGE_DIALOG, NULL,
 			   glade_standard_build_children, NULL);
     glade_register_widget (GTK_TYPE_NOTEBOOK, glade_standard_build_widget,
@@ -1300,15 +1185,11 @@ _glade_init_gtk_widgets(void)
 			   glade_standard_build_children, NULL);
     glade_register_widget (GTK_TYPE_RADIO_MENU_ITEM, glade_standard_build_widget,
 			   menuitem_build_children, NULL);
-    glade_register_widget (GTK_TYPE_RADIO_TOOL_BUTTON, glade_standard_build_widget,
-			   NULL, NULL);
     glade_register_widget (GTK_TYPE_SCROLLED_WINDOW, glade_standard_build_widget,
 			   glade_standard_build_children,
 			   scrolled_window_find_internal_child);
     glade_register_widget (GTK_TYPE_SEPARATOR_MENU_ITEM, glade_standard_build_widget,
 			   NULL, NULL);
-    glade_register_widget (GTK_TYPE_SEPARATOR_TOOL_ITEM, glade_standard_build_widget,
-			   NULL, NULL);
 #ifdef HAVE_GTK_PLUG
     glade_register_widget (GTK_TYPE_SOCKET, glade_standard_build_widget,
 			   NULL, NULL);
@@ -1329,14 +1210,8 @@ _glade_init_gtk_widgets(void)
 			   NULL, NULL);
     glade_register_widget (GTK_TYPE_TOGGLE_BUTTON, glade_standard_build_widget,
 			   glade_standard_build_children, NULL);
-    glade_register_widget (GTK_TYPE_TOGGLE_TOOL_BUTTON, glade_standard_build_widget,
-			   NULL, NULL);
     glade_register_widget (GTK_TYPE_TOOLBAR, glade_standard_build_widget,
 			   toolbar_build_children, NULL);
-    glade_register_widget (GTK_TYPE_TOOL_ITEM, glade_standard_build_widget,
-			   glade_standard_build_children, NULL);
-    glade_register_widget (GTK_TYPE_TOOL_BUTTON, glade_standard_build_widget,
-			   NULL, NULL);
     glade_register_widget (GTK_TYPE_TREE, glade_standard_build_widget,
 			   NULL, NULL);
     glade_register_widget (GTK_TYPE_TREE_VIEW, glade_standard_build_widget,
